// -> Florent Pagès 2017-2018 http://tuto.pages-informatique.com/z-wc7-webcreator.php <-

// version 0.7.3 du 20180517 -- > Correction bug de timer si multiple stop / start
// version 0.7.2 du 20180514 -- > Un tab_defilementStart ou tab_defilementStartStop provoque un changement de diapo.
// version 0.7.1 du 20180514 -- > correction bug défilement auto qui se lance trop tot.
// version 0.7  du 20180512  --> Ajout de fonctions pour le défilement automatique des onglets. 
// version 0.6  du 20180406  --> Ajout des fonctions de scroll doux bas et haut de page
// version 0.5  du 201804    --> ajout de commentaires  
// version 0.4  du 20180128  --> fusion avec autres version toolwc et 
// version 0.3  --> ajout diaporama_Resise et  panelExt_Resize pour prendre en cpte bandeau extensible
// version 0.2  du 20170209
// version 0.1  du 20170205 --> fonction sur les onglets pour changer l'onglet courant
//
// Ce fichier fourni des fonctions javascript pour agir sur une page
// web créée avec webcreator 7.2  ( ca pourrait marcher avec des versions plus basse non testé)
//
// Ce fichier doit être placé dans le dossier web de votre projet.
// Vous devez ajouter dans la section code perso : 
// dans la section head : <script type="text/javascript" src="toolwc7.js"></script>
//  


///////////////////////////////
// Fonctions Générales
//////////////////////////////

// retourn l'objet LMObject de nom pId
function  getLMObjectById(pId) {
	for (i = 0; i < LMObjects.length ; i++ ) {
		if (LMObjects[i].id == pId) return LMObjects[i];
	}
	return undefined;
}



///////////////////////////////
// Fonctions Ajoute un div vide juste après le body.
//////////////////////////////
function bodyAjouteDiv() {	
	var para = document.createElement("div");
	para.className = "MaBande";
	var obody = document.getElementsByTagName("BODY")[0];	
	obody.insertBefore(para, obody.firstChild);
	return true;
}


///////////////////////////////
// Fonctions Pour manipuler un objet Tab (onglets)
//////////////////////////////

// pId est est nom de l'objet Onglet par exemple "TabCtl1" ou l'objet onglet lui meme
// pNumtab : change l'onglet actif il devient celui en pNumtab Position 
// retourn l'objet tab
function tab_Change(pId, pNumtab) {
	var otab;
	if (pId instanceof LMObject ) { 
		otab = pId; 
	}
	else { 
		otab = getLMObjectById(pId); 
	}
	otab.SetSelectedTab(pNumtab);
	return otab;
}

// retourne le numéro de l'onglet selectionné (1 pour le premier... )
function tab_GetSelected(pId) {
	var otab;
	if (pId instanceof LMObject ) { 
		otab = pId; 
	}
	else { 
		otab = getLMObjectById(pId); 
	}
	
    var i;
    for (i=1; i<=otab.nbtabs; i++)    {
        var tabid= otab.id + "_tab" + i;
        var divtab= document.getElementById(tabid);
		if (divtab.isactive) return i;
    }
	return -1;
}

// retourne le nombre d'onglets
function tab_GetNbTabs(pId)  {
	var otab;
	if (pId instanceof LMObject ) { 
		otab = pId; 
	}
	else { 
		otab = getLMObjectById(pId); 
	}	
	return otab.nbtabs;	
}

// selectionne l'onglet suivant si le dernier est sélectionné
// pId : nom de l'objet onglet ou l'onglet lui meme.
function tab_ChangeNext(pId) {
	var otab;
	if (pId instanceof LMObject ) { 
		otab = pId; 
	}
	else { 
		otab = getLMObjectById(pId); 
	}
	var t = 0;
	t = tab_GetSelected(otab);
	if (t < tab_GetNbTabs(otab)) {
		t++;
	} else {  
       t = 1;
	}
	return tab_Change(otab, t);
}


// selectionne l'onglet precedent 
// pId : nom de l'objet onglet ou l'onglet lui meme.
function tab_ChangePrevious(pId) {
	var otab;
	if (pId instanceof LMObject ) { 
		otab = pId; 
	}
	else { 
		otab = getLMObjectById(pId); 
	}
	var t = 0;
	t = tab_GetSelected(otab);
	if (t > 1) {
		t--;
	} else {  
       t = tab_GetNbTabs(otab);
	}
	return tab_Change(otab, t);
}

// Défilement initilisation du défilement auto des onglets 
//pId,     // Nom de l'objet tab
//pAutoChange,  // true défilement auto activé sinon false
//pTimeOut    // délais entre deux onglets en milisecondes
//
function tab_defilementAutoInit(pId,  pAutoChange, pTimeOut   ) {
	var  otab = getLMObjectById(pId);
	otab.wct_timeout = pTimeOut;									 
	
	if (pAutoChange)  {  
	   otab.wct_autoChange = true; 
       otab.wct_timer = setTimeout(function(){tab_defilementDiapo(pId);}, otab.wct_timeout );		
	} else { 
		otab.wct_autoChange = false;  
	}
	
	return otab;								 
}



function tab_defilementStart(pId) {

   var  otab = getLMObjectById(pId);
   
   
   // if (otab.wct_autoChange) return otab; // Le défilement auto est déjà activé.
 
   
   otab.wct_autoChange = true;     // Active Le défilement auto 
   
   if (otab.wct_timeout === undefined) {  // Si l'objet est mal initialisé timeout à 1 seconde
      otab.wct_timeout = 1000;
   }
   
   if (otab.wct_autoChange) {
	   if (otab.wct_timer !== undefined)  { clearTimeout(otab.wct_timer); }
       tab_ChangeNext(pId);
       otab.wct_timer = setTimeout(function(){tab_defilementDiapo(pId);}, otab.wct_timeout );
   }

   return otab;
}



function tab_defilementStop(pId) { // arrête le défilement automatique des onglet.

   var  otab = getLMObjectById(pId);

   if (otab.wct_autoChange === undefined) {  // si objet mal initialisé défilement 
      otab.wct_autoChange = false;
   } else {
      otab.wct_autoChange = false;
   }
   
   if (otab.wct_timeout === undefined) {  // Si l'objet est mal initialisé timeout  à 1 seconde
      otab.wct_timeout = 1000;
   }
   
   if (otab.wct_timer !== undefined)  { clearTimeout(otab.wct_timer); }   
   
   return otab;
}


function tab_defilementStartStop(pId) {  // Commute marche et arret du diaporama.

   var  otab = getLMObjectById(pId);

   if (otab.wct_autoChange === undefined) {  // si objet mal initialisé défilement 
      otab.wct_autoChange = false;
   } else {
      otab.wct_autoChange = !otab.wct_autoChange;
   }
   
   if (otab.wct_timeout === undefined) {  // Si l'objet est mal initialisé timeout  à 1 seconde
      otab.wct_timeout = 1000;
   }

   if (otab.wct_autoChange) {
	   if (otab.wct_timer !== undefined)  { clearTimeout(otab.wct_timer); }	   
	   tab_ChangeNext(pId);
       otab.wct_timer = setTimeout(function(){tab_defilementDiapo(pId);} , otab.wct_timeout );
   }   
   
}

// Ne pas appeler directement. Est appelé via SetTimeout.
function tab_defilementDiapo(pId) { //
	
   if (pId === undefined ) return ;
	
   var  otab = getLMObjectById(pId);

   if (otab.wct_autoChange){
    if (otab.wct_timer !== undefined)  { clearTimeout(otab.wct_timer); }		   
    tab_ChangeNext(pId);
    otab.wct_timer = setTimeout(function(){tab_defilementDiapo(pId);}, otab.wct_timeout );
   }
}


///////////////////////////////
// Fonctions d action basique sur les objets
// 
//////////////////////////////

// le body est ce qui est derrière la page WC7 mais utiliser plutot la couleur de la page dans wc.
// pColor est une couleur au format css par exemple : "red" ou "#a14c12"
function body_couleur(pColor) {
	var o;
	o = document.getElementsByTagName("body");
	o[0].style.backgroundColor = pColor;
}


function page_couleur(pColor) {
	var o;
	o = document.getElementById("Page");
	o.style.backgroundColor = pColor;
}

// Déclenche un défilement doux vers le haut de la page
function body_scrollDouxEnHaut() {
	  $("html, body").animate({ scrollTop: 0 }, "slow");
}


// Déclenche un défilement doux vers le bas de la page
function body_scrollDouxEnBas() {
     var bottom = $(document).height() - $(window).height(); 
	 $("HTML, BODY").animate({ scrollTop: bottom }, 1000);	
}


// change la couleur de fond d'un objet panel ou box 
// (remarque : Evitez les box pour faire du responsive choisir des panels à la place.)
// attention ecrase les paramètre d'affichage de l'objet en question
// sur la page web
// pId : nom de l'objet dont il faut changer la couleur.
// pColor :  est une couleur au format css par exemple : "red" ou "#a14c12"
function obj_SetCouleur(pId, pColor) {
	var o, olm;
	o = document.getElementById(pId);
	olm = getLMObjectById(pId); 
	
	o.style.background = pColor;
	o.style.backgroundColor = pColor;
	
	// masquage des #PanelAlpha et #PanelNoAlpha
	oalpha = document.getElementById(pId+"Alpha");
	onoalpha = document.getElementById(pId+"NoAlpha");
	if (oalpha)  oalpha.style.display = "none";
	if (onoalpha) onoalpha.style.display = "none";	
}








///////////////////////////////
// Fonctions Pour le responsive et le controle de la page par programmation
// 
//////////////////////////////

var PHONEWIDTH = 460;  // Lageur en dessous de laquelle c'est un ecran de telephone
var PHONEPOURCENT = "95%";




// retourne la largeur d'affichage visible dans le navigateur
// en pixels virtuel (pixels device independant)
function getLargeurAffichage() {
  return Math.min( window.innerWidth , screen.width,  screen.availWidth);

}


var tabObjResized = [];  // Stocke les noms des objets afin de retablir la taille d origine
tabObjResized.initOk = false;

function restaureTailleOri() { 
	 for (i = 0; i < tabObjResized.length; i++)  {
		 obj_RestaureTailleOri(tabObjResized[i]);
	 }
}


// Restaure la taille d'origine
function obj_RestaureTailleOri(pId) {
	var otab;
	if (pId instanceof LMObject ) { 
		otab = pId; 
	}
	else { 
		otab = getLMObjectById(pId); 
	}	
	
	var o = document.getElementById(pId); 	
	var olm = getLMObjectById(pId); 	
	
	if (olm) {
		o.style.width = olm.oriw+"px";
		o.style.height = olm.orih+"px";	
		
	}
	return olm;
}


function obj_AffichePas(o) {
	o.style.display = "none";	
	var olm = LMObjects[o.LMObjectsIdx]; // Eviter que l'objet ne soit affiché par LMObjectAnimateElem(...)
	olm.visible = 0; 
	olm.displayenable = false;	
}


function obj_Affichable(o) {
	return;
/*	o.style.display = "block";	
	var olm = LMObjects[o.LMObjectsIdx]; // Eviter que l'objet ne soit affiché par LMObjectAnimateElem(...)
	olm.visible = 1; 
	olm.displayenable = true;	*/
}



function obj_CentragePhone(o) {
	    //
	    var opepadding = window.getComputedStyle(o.parentElement, null).getPropertyValue('padding-left');
		opepadding =  parseInt(opepadding,10); //	console.log(opepadding);
	    var opemargin = window.getComputedStyle(o.parentElement, null).getPropertyValue('margin-left');		
		opemargin =  parseInt(opemargin,10); //console.log(opemargin);
	parseInt('245px', 10);
		delta = ((o.parentElement.GetWidth() -  o.GetWidth()) / 2) - (opepadding + opemargin) ;  // permet de center 
		o.style.marginLeft = delta + "px";
		//o.style.marginRight = delta + "px";	
}


// Fonctions de Resize des éléments pour les mettre 
// pId : nom de l'objet titre
// pWidth : largeur de La fenêtre d'affichage du site.
// pW : % d'affichage : "50%", si rien par défaut "90%"
// pWTel : % d'affichage pour un tel portable ou 0 si pas d'affichage.
// cas des éléments Hn a la generation
// les éléments Hn sont contenus dans un div contenant. exemple 
//<div id="Titre3" style="display: block;">
//<h2>Dépannage informatique à Marseille</h2>
//</div>
function hn_Resize(pId, pWidth,  pW, pWTel)  {
	var o = document.getElementById(pId); 
	if(o) {
		if (!tabObjResized.initOk)	tabObjResized.push(pId); //Enregistre l'oject etant retaillé			
		if (pWidth <= PHONEWIDTH) { 
			if (pWTel === undefined) pWTel = PHONEPOURCENT ;
			pW = pWTel;	
		} 
		if (pW === undefined)  pW = "90%";
		if (pW === 0) {
			obj_AffichePas(o);
		} else {
			obj_Affichable(o);			
			o.style.width = pW;	
			o.style.height = "initial";	
			o.style.textAlign = "center";
		}
		// Centrage dans le cas des téléphone	
		if (pWidth <= PHONEWIDTH) { obj_CentragePhone(o);  }
	}

}


// cas des élément img en fait contenu dans un div
// id="ImgToto"  ->  <div id="ImgToto"> <img id="ImgTotoInner"></div>
function img_Resize(pId, pWidth, pW, pWTel) {
	var o = document.getElementById(pId); 	
	if(o) {
		if (!tabObjResized.initOk)	tabObjResized.push(pId); //Enregistre l'oject etant retaillé		
		if (pWidth <= PHONEWIDTH) { 
			if (pWTel === undefined) pWTel = PHONEPOURCENT ;
			pW = pWTel;	
		} 
		if (pW === undefined)  pW = "90%";
		if (pW === 0) { // cas pas d'affichage
			obj_AffichePas(o);
		} else {
			obj_Affichable(o);				
			o.style.width = pW;
			o.style.height  = "initial";
			o.style.textAlign = "center";
			o.style.minWidth = "40px";
			
		/*	if (pWidth <= PHONEWIDTH) 
				o.children[0].style.width = pW; 
			else o.children[0].style.width = pW;    */
			o.children[0].style.width = "100%";
			o.children[0].style.height = "initial";
			o.children[0].style.position = "relative"; // en remplacement de position: absolute;
			
		}
		// Centrage dans le cas des téléphone	
		if (pWidth <= PHONEWIDTH) { obj_CentragePhone(o);  }		
	}	

}


function text_Resize(pId, pWidth, pW, pWTel) {
	var o = document.getElementById(pId); 
	if(o) {
		if (!tabObjResized.initOk)	tabObjResized.push(pId); //Enregistre l'oject etant retaillé		
		if (pWidth <= PHONEWIDTH) {			
		    if (pWTel === undefined) pWTel = PHONEPOURCENT;
			pW = pWTel;		
		} 
		if (pW === undefined)  pW = "90%";
		if (pW === 0) { // cas pas d'affichage
			obj_AffichePas(o);
		} else {
			obj_Affichable(o);				
			o.style.width = pW;
			o.style.height = "initial"; // permet a la zone de s'agrandir en hauteur
		}
		// Centrage dans le cas des téléphone	
		if (pWidth <= PHONEWIDTH) { obj_CentragePhone(o);  }		
	}	
}

// Pour les boutons V7
function but7_Resize(pId, pWidth, pW, pWTel) {
	var o = document.getElementById(pId);		
	if(o) {
		if (!tabObjResized.initOk)	tabObjResized.push(pId); //Enregistre l'oject etant retaillé		
		if (pWidth <= PHONEWIDTH) { 			
		    if (pWTel === undefined) pWTel = PHONEPOURCENT ;
			pW = pWTel;		
		} 
		if (pW === undefined)  pW = "90%";
		if (pW === 0) { // cas pas d'affichage
			obj_AffichePas(o);
		} else {
			obj_Affichable(o);				
			o.style.width = pW;	
			o.style.whiteSpace = "normal";  // saut de ligne automatique (!= nowrap)
		   // o.style.marginLeft = "auto";
		   // o.style.marginRight = "auto";
			delta = (o.parentElement.GetWidth() -  o.GetWidth()) / 2;  // permet de center l'element par rapport à son conteneur.
			o.style.marginLeft = delta + "px";
			//o.style.marginRight = delta + "px";	   
		}
		// Centrage dans le cas des téléphone	
		if (pWidth <= PHONEWIDTH) { obj_CentragePhone(o);  o.style.height = "initial"; }		
	}	
}

function panel_Resize(pId, pWidth, pW, pWTel) {
	var o = document.getElementById(pId);
	if(o) {	
		if (!tabObjResized.initOk)	tabObjResized.push(pId); //Enregistre l'oject etant retaillé	
		if (pWidth <= PHONEWIDTH) { 
			if (pWTel === undefined) pWTel = PHONEPOURCENT ;
			pW = pWTel;	
		} 
		if (pW === undefined)  pW = "90%";
		if (pW === 0) { // cas pas d'affichage
			obj_AffichePas(o);
		} else {
			obj_Affichable(o);				
			o.style.width = pW;	
			o.style.height = "initial";
			o.style.minHeight = "1px";
			//o.style.marginLeft = "auto";
			//o.style.marginRight = "auto";	
		   // o.style.marginTop = "auto";
			o.style.marginButtom = "auto";		
		}
		// Centrage dans le cas des téléphone	
		if (pWidth <= PHONEWIDTH) { obj_CentragePhone(o);  }		
	}	
}  



function panelExtensible_Resize(pId, pWidth, pW, pWTel) {
	
    panel_Resize(pId , pWidth, pW, pWTel);	
	var a;
	a = document.getElementById(pId);
	a.style.minWidth = "340px";
	var x; 
	x = document.getElementById("Page").GetWidth() ;
	
	a.style.width = x + "px";

    panel_Resize(pId + "_extensible", pWidth, pW, pWTel);	
    panel_Resize(pId + "_placeholder", pWidth, pW, pWTel);
    panel_Resize(pId + "_placeholder_extensible", pWidth, pW, pWTel);
}  


///////////////////////////////////////

function diaporama_Resize(pId, pWidth, pW, pWTel) {
	
	var Id_placeholder = pId + "_placeholder";
	var Id_placeholder = pId;	
	var o = document.getElementById(pId);
	if(o) {	
		if (!tabObjResized.initOk)	tabObjResized.push(pId); //Enregistre l'oject etant retaillé	
		if (pWidth <= PHONEWIDTH) { 
			if (pWTel === undefined) pWTel = PHONEPOURCENT ;
			pW = pWTel;	
		} 
		if (pW === undefined)  pW = "90%";
		
		
		
		if (pW === 0) { // cas pas d'affichage
			//obj_AffichePas(o);
			o.style.display = "none !important";
			o.style.display = "none !important";	
			o.style.display = "none !important";

		   setTimeout(function(){
				   if(is.ns) Diaporama1=document.getElementById("Diaporama1");
				   Diaporama1.Hide();},100);


			
		} else {
			obj_Affichable(o);				
			o.style.width = pW;	
			o.style.height = "initial";
			o.style.minHeight = "1px";
			//o.style.marginLeft = "auto";
			//o.style.marginRight = "auto";	
		   // o.style.marginTop = "auto";
			o.style.marginButtom = "auto";		
			
		   setTimeout(function(){
				   if(is.ns) Diaporama1=document.getElementById("Diaporama1");
				   Diaporama1.Show();},100);

			var dipao = document.getElementById("Diaporama1");
			dipao.childNodes[0].style.width = document.getElementById("Page").offsetWidth + "px";
			
		}
		// Centrage dans le cas des téléphone	
		//if (pWidth <= PHONEWIDTH) { obj_CentragePhone(o);  }		
	}	
}  


///////////////////////////////////////

/////////////////


function menuOnOff() {
    var x = document.getElementById("fps-menu1");
	var t = ["fps-menu2", "fps-menu3", "fps-menu4", "fps-menu5", "fps-menu6", "fps-menu7"];
    if (x.className === "respmenu") {
        x.className = "";
		for ( i = 0 ; i < t.length; i++) {
			x = document.getElementById(t[i]);
			x.className = "";
		}
    } else {
        x.className = "respmenu";
		for ( i = 0 ; i < t.length; i++) {
			x = document.getElementById(t[i]);
			x.className = "respmenu";
		}		
    }
}
